==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/CollectionActivation.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;
using com.db4o.ext;

namespace com.db4o.test
{

    public class CollectionActivation
    {
        IList myList;
        static long id;

        public void storeOne()
        {
            ExtObjectContainer objectContainer = Tester.objectContainer();
            myList = objectContainer.collections().newLinkedList();
            CollectionActivationElement cae = new CollectionActivationElement("test");
			cae.value = 42;
            objectContainer.set(cae);
            id = objectContainer.getID(cae);
            myList.Add(cae);
        }

        public void testOne()
        {   
			CollectionActivationElement cae = null;

			ExtObjectContainer objectContainer = Tester.objectContainer();
			objectContainer.activate(this, int.MaxValue);

            cae = (CollectionActivationElement)objectContainer.getByID(id);
            Tester.ensure("objects got by id should not be activated", cae.name == null);

            cae = (CollectionActivationElement)myList[0];
            Tester.ensure(cae.name != null && cae.name == "test");
			Tester.ensure(42 == cae.value);
        }
    }

    public class CollectionActivationElement
    {
        public String name;

		public int value;

        public CollectionActivationElement(){}

        public CollectionActivationElement(String name){
            this.name = name;
        }
    }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/CollectionActivation.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;
using com.db4o.ext;

namespace com.db4o.test
{

    public class CollectionActivation
    {
        IList myList;
        static long id;

        public void StoreOne()
        {
            ExtObjectContainer objectContainer = Tester.ObjectContainer();
            myList = objectContainer.Collections().NewLinkedList();
            CollectionActivationElement cae = new CollectionActivationElement("test");
			cae.value = 42;
            objectContainer.Set(cae);
            id = objectContainer.GetID(cae);
            myList.Add(cae);
        }

        public void TestOne()
        {   
			CollectionActivationElement cae = null;

			ExtObjectContainer objectContainer = Tester.ObjectContainer();
			objectContainer.Activate(this, int.MaxValue);

            cae = (CollectionActivationElement)objectContainer.GetByID(id);
            Tester.Ensure("objects got by id should not be activated", cae.name == null);

            cae = (CollectionActivationElement)myList[0];
            Tester.Ensure(cae.name != null && cae.name == "test");
			Tester.Ensure(42 == cae.value);
        }
    }

    public class CollectionActivationElement
    {
        public String name;

		public int value;

        public CollectionActivationElement(){}

        public CollectionActivationElement(String name){
            this.name = name;
        }
    }
}
